@@ -1738,6 +1738,8 @@ enum {
 	WP_FIFO_ERROR_BIT,
 	WP_CRC_ERROR_BIT,
 	WP_ABORT_ERROR_BIT,
+	WP_FRAME_ERROR_BIT,
+	WP_DMA_ERROR_BIT,
 };
 
 
