@@ -426,7 +426,7 @@ void adsl_tty_receive(void *tty_ptr, unsigned char *pData,
 	const struct tty_ldisc *ops = &tp->ldisc;
 #endif
 	WAN_ASSERT1((tp==NULL));
-	ops->receive_buf(tp, pData, pFlags, dataLen);
+	ops->receive_buf(tp, pData, NULL, dataLen);
 #endif	
 }
 
