@@ -84,12 +84,14 @@
 					(WAN_TE3_BIT_LOS_ALARM |	\
 					 WAN_TE3_BIT_YEL_ALARM |	\
 					 WAN_TE3_BIT_OOF_ALARM))
-#endif
+#else
 
 #define IS_E3_ALARM(alarm)	((alarm) &				\
 					(WAN_TE3_BIT_YEL_ALARM |	\
 					 WAN_TE3_BIT_OOF_ALARM))
 
+#endif
+
 /******************************************************************************
 **			  FUNCTION DEFINITIONS
 ******************************************************************************/
@@ -187,8 +189,6 @@ static int sdla_te3_get_fe_status(sdla_fe_t *fe, unsigned char *status, int notu
 static int sdla_te3_polling(sdla_fe_t *fe)
 {
     int err;
-	int prev_status=fe->fe_status;
-	sdla_t	*card = (sdla_t*)fe->card;
 
 	err=sdla_te3_read_alarms(fe, WAN_FE_ALARM_READ|WAN_FE_ALARM_UPDATE);
 	
